@@ -31,6 +31,7 @@ from google.oauth2 import service_account  # type: ignore
 from google.cloud.video.transcoder_v1beta1.services.transcoder_service import pagers
 from google.cloud.video.transcoder_v1beta1.types import resources
 from google.cloud.video.transcoder_v1beta1.types import services
+from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
 
 from .transports.base import TranscoderServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import TranscoderServiceGrpcAsyncIOTransport
@@ -53,12 +54,53 @@ class TranscoderServiceAsyncClient:
     DEFAULT_MTLS_ENDPOINT = TranscoderServiceClient.DEFAULT_MTLS_ENDPOINT
 
     job_path = staticmethod(TranscoderServiceClient.job_path)
-
+    parse_job_path = staticmethod(TranscoderServiceClient.parse_job_path)
     job_template_path = staticmethod(TranscoderServiceClient.job_template_path)
+    parse_job_template_path = staticmethod(
+        TranscoderServiceClient.parse_job_template_path
+    )
+
+    common_billing_account_path = staticmethod(
+        TranscoderServiceClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        TranscoderServiceClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(TranscoderServiceClient.common_folder_path)
+    parse_common_folder_path = staticmethod(
+        TranscoderServiceClient.parse_common_folder_path
+    )
+
+    common_organization_path = staticmethod(
+        TranscoderServiceClient.common_organization_path
+    )
+    parse_common_organization_path = staticmethod(
+        TranscoderServiceClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(TranscoderServiceClient.common_project_path)
+    parse_common_project_path = staticmethod(
+        TranscoderServiceClient.parse_common_project_path
+    )
+
+    common_location_path = staticmethod(TranscoderServiceClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        TranscoderServiceClient.parse_common_location_path
+    )
 
     from_service_account_file = TranscoderServiceClient.from_service_account_file
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> TranscoderServiceTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            TranscoderServiceTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(TranscoderServiceClient).get_transport_class, type(TranscoderServiceClient)
     )
@@ -85,16 +127,19 @@ class TranscoderServiceAsyncClient:
             client_options (ClientOptions): Custom options for the client. It
                 won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
-                default endpoint provided by the client. GOOGLE_API_USE_MTLS
+                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                 environment variable can also be used to override the endpoint:
                 "always" (always use the default mTLS endpoint), "never" (always
-                use the default regular endpoint, this is the default value for
-                the environment variable) and "auto" (auto switch to the default
-                mTLS endpoint if client SSL credentials is present). However,
-                the ``api_endpoint`` property takes precedence if provided.
-                (2) The ``client_cert_source`` property is used to provide client
-                SSL credentials for mutual TLS transport. If not provided, the
-                default SSL credentials will be used if present.
+                use the default regular endpoint) and "auto" (auto switch to the
+                default mTLS endpoint if client certificate is present, this is
+                the default value). However, the ``api_endpoint`` property takes
+                precedence if provided.
+                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
+                is "true", then the ``client_cert_source`` property can be used
+                to provide client certificate for mutual TLS transport. If
+                not provided, the default SSL client certificate will be used if
+                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
+                set, no client certificate will be used.
 
         Raises:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
@@ -150,7 +195,8 @@ class TranscoderServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, job]):
+        has_flattened_params = any([parent, job])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -226,7 +272,8 @@ class TranscoderServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -301,7 +348,8 @@ class TranscoderServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -366,7 +414,8 @@ class TranscoderServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -435,7 +484,8 @@ class TranscoderServiceAsyncClient:
                 resource name.
 
                 This value should be 4-63 characters, and valid
-                characters are ``/[a-zA-Z0-9_-_]/``.
+                characters must match the regular expression
+                ``[a-zA-Z][a-zA-Z0-9_-]*``.
                 This corresponds to the ``job_template_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -453,7 +503,8 @@ class TranscoderServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, job_template, job_template_id]):
+        has_flattened_params = any([parent, job_template, job_template_id])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -532,7 +583,8 @@ class TranscoderServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -608,7 +660,8 @@ class TranscoderServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -673,7 +726,8 @@ class TranscoderServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
